@@ -430,7 +430,15 @@ def coefficient_of_variation(data: list) -> float:
 def kurtosis_skewness(data: list):
     """求一组数据的峰度 kurtosis 和 偏度 Skewness。
 
-    正态分布的峰度为3，若峰度大于0，则说明该组数据的分布曲线相较于正态分布更加陡峭；若峰度小于0，则说明该组数据的分布曲线相较于正态分布更加平缓。换言之，峰度越大，则数据在靠近均值的部分分布得越多，在距离均值较远的部分分布得较少。
+    解释：
+    如果一个分布服从正态分布，那么说明该分布受到多种因素的影响，
+    且影响因素是彼此独立的，对结果的影响是相加的。
+    若对结果的影响是相乘的，那么就是对数正态分布。
+    如果分布的峰度绝对值小于10，并且偏度绝对值小于3，那么可接受为正态分布。
+
+    正态分布的峰度为3，若峰度大于0，则说明该组数据的分布曲线相较于正态分布更加陡峭；
+    若峰度小于0，则说明该组数据的分布曲线相较于正态分布更加平缓。
+    换言之，峰度越大，则数据在靠近均值的部分分布得越多，在距离均值较远的部分分布得较少。
     峰度可以用来衡量风险，同样的方差下，峰度越高，越容易取极端值，风险越大。
     峰度可以帮助衡量众数的统计学意义，峰度越高，众数在描述该组数据的集中趋势的作用就越高。
 
